from tkinter import*

print("I TOLD YOU THIS IS NOTHING!")

window = Tk()
window.title("Nothing")
canvas = Canvas(bg="red")
canvas.pack()
lable = Label(text="I TOLD YOU THIS IS NOTHING!")
lable.pack()
window.mainloop()
